# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['UserNotificationRuleArgs', 'UserNotificationRule']

@pulumi.input_type
class UserNotificationRuleArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[str],
                 user_id: pulumi.Input[str],
                 duration: Optional[pulumi.Input[int]] = None,
                 important: Optional[pulumi.Input[bool]] = None,
                 position: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a UserNotificationRule resource.
        :param pulumi.Input[str] type: The type of notification rule. Can be wait, notify*by*slack, notify*by*msteams, notify*by*sms, notify*by*phone*call, notify*by*telegram, notify*by*email, notify*by*mobile*app, notify*by*mobile*app*critical. NOTE: `notify_by_msteams` is only available for Grafana Cloud customers.
        :param pulumi.Input[str] user_id: User ID
        :param pulumi.Input[int] duration: A time in seconds to wait (when `type=wait`). Can be 60, 300, 900, 1800, 3600
        :param pulumi.Input[bool] important: Boolean value which indicates if a rule is “important”
        :param pulumi.Input[int] position: Personal notification rules execute one after another starting from position=0. A new escalation policy created with a position of an existing escalation policy will move the old one (and all following) down on the list.
        """
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "user_id", user_id)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if important is not None:
            pulumi.set(__self__, "important", important)
        if position is not None:
            pulumi.set(__self__, "position", position)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The type of notification rule. Can be wait, notify*by*slack, notify*by*msteams, notify*by*sms, notify*by*phone*call, notify*by*telegram, notify*by*email, notify*by*mobile*app, notify*by*mobile*app*critical. NOTE: `notify_by_msteams` is only available for Grafana Cloud customers.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[str]:
        """
        User ID
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_id", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[int]]:
        """
        A time in seconds to wait (when `type=wait`). Can be 60, 300, 900, 1800, 3600
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter
    def important(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean value which indicates if a rule is “important”
        """
        return pulumi.get(self, "important")

    @important.setter
    def important(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "important", value)

    @property
    @pulumi.getter
    def position(self) -> Optional[pulumi.Input[int]]:
        """
        Personal notification rules execute one after another starting from position=0. A new escalation policy created with a position of an existing escalation policy will move the old one (and all following) down on the list.
        """
        return pulumi.get(self, "position")

    @position.setter
    def position(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "position", value)


@pulumi.input_type
class _UserNotificationRuleState:
    def __init__(__self__, *,
                 duration: Optional[pulumi.Input[int]] = None,
                 important: Optional[pulumi.Input[bool]] = None,
                 position: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering UserNotificationRule resources.
        :param pulumi.Input[int] duration: A time in seconds to wait (when `type=wait`). Can be 60, 300, 900, 1800, 3600
        :param pulumi.Input[bool] important: Boolean value which indicates if a rule is “important”
        :param pulumi.Input[int] position: Personal notification rules execute one after another starting from position=0. A new escalation policy created with a position of an existing escalation policy will move the old one (and all following) down on the list.
        :param pulumi.Input[str] type: The type of notification rule. Can be wait, notify*by*slack, notify*by*msteams, notify*by*sms, notify*by*phone*call, notify*by*telegram, notify*by*email, notify*by*mobile*app, notify*by*mobile*app*critical. NOTE: `notify_by_msteams` is only available for Grafana Cloud customers.
        :param pulumi.Input[str] user_id: User ID
        """
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if important is not None:
            pulumi.set(__self__, "important", important)
        if position is not None:
            pulumi.set(__self__, "position", position)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[int]]:
        """
        A time in seconds to wait (when `type=wait`). Can be 60, 300, 900, 1800, 3600
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter
    def important(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean value which indicates if a rule is “important”
        """
        return pulumi.get(self, "important")

    @important.setter
    def important(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "important", value)

    @property
    @pulumi.getter
    def position(self) -> Optional[pulumi.Input[int]]:
        """
        Personal notification rules execute one after another starting from position=0. A new escalation policy created with a position of an existing escalation policy will move the old one (and all following) down on the list.
        """
        return pulumi.get(self, "position")

    @position.setter
    def position(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "position", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of notification rule. Can be wait, notify*by*slack, notify*by*msteams, notify*by*sms, notify*by*phone*call, notify*by*telegram, notify*by*email, notify*by*mobile*app, notify*by*mobile*app*critical. NOTE: `notify_by_msteams` is only available for Grafana Cloud customers.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[str]]:
        """
        User ID
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_id", value)


class UserNotificationRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 important: Optional[pulumi.Input[bool]] = None,
                 position: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/personal_notification_rules/)

        **Note**: you must be running Grafana OnCall >= v1.8.0 to use this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_grafana as grafana
        import pulumiverse_grafana as grafana

        my_user = grafana.onCall.get_user(username="my_username")
        my_user_step1 = grafana.on_call.UserNotificationRule("my_user_step_1",
            user_id=my_user.id,
            position=0,
            type="notify_by_mobile_app")
        my_user_step2 = grafana.on_call.UserNotificationRule("my_user_step_2",
            user_id=my_user.id,
            position=1,
            duration=600,
            type="wait")
        my_user_step3 = grafana.on_call.UserNotificationRule("my_user_step_3",
            user_id=my_user.id,
            position=2,
            type="notify_by_phone_call")
        my_user_step4 = grafana.on_call.UserNotificationRule("my_user_step_4",
            user_id=my_user.id,
            position=3,
            duration=300,
            type="wait")
        my_user_step5 = grafana.on_call.UserNotificationRule("my_user_step_5",
            user_id=my_user.id,
            position=4,
            type="notify_by_slack")
        my_user_important_step1 = grafana.on_call.UserNotificationRule("my_user_important_step_1",
            user_id=my_user.id,
            important=True,
            position=0,
            type="notify_by_mobile_app_critical")
        my_user_important_step2 = grafana.on_call.UserNotificationRule("my_user_important_step_2",
            user_id=my_user.id,
            important=True,
            position=1,
            duration=300,
            type="wait")
        my_user_important_step3 = grafana.on_call.UserNotificationRule("my_user_important_step_3",
            user_id=my_user.id,
            important=True,
            position=2,
            type="notify_by_mobile_app_critical")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:onCall/userNotificationRule:UserNotificationRule name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] duration: A time in seconds to wait (when `type=wait`). Can be 60, 300, 900, 1800, 3600
        :param pulumi.Input[bool] important: Boolean value which indicates if a rule is “important”
        :param pulumi.Input[int] position: Personal notification rules execute one after another starting from position=0. A new escalation policy created with a position of an existing escalation policy will move the old one (and all following) down on the list.
        :param pulumi.Input[str] type: The type of notification rule. Can be wait, notify*by*slack, notify*by*msteams, notify*by*sms, notify*by*phone*call, notify*by*telegram, notify*by*email, notify*by*mobile*app, notify*by*mobile*app*critical. NOTE: `notify_by_msteams` is only available for Grafana Cloud customers.
        :param pulumi.Input[str] user_id: User ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserNotificationRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/personal_notification_rules/)

        **Note**: you must be running Grafana OnCall >= v1.8.0 to use this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_grafana as grafana
        import pulumiverse_grafana as grafana

        my_user = grafana.onCall.get_user(username="my_username")
        my_user_step1 = grafana.on_call.UserNotificationRule("my_user_step_1",
            user_id=my_user.id,
            position=0,
            type="notify_by_mobile_app")
        my_user_step2 = grafana.on_call.UserNotificationRule("my_user_step_2",
            user_id=my_user.id,
            position=1,
            duration=600,
            type="wait")
        my_user_step3 = grafana.on_call.UserNotificationRule("my_user_step_3",
            user_id=my_user.id,
            position=2,
            type="notify_by_phone_call")
        my_user_step4 = grafana.on_call.UserNotificationRule("my_user_step_4",
            user_id=my_user.id,
            position=3,
            duration=300,
            type="wait")
        my_user_step5 = grafana.on_call.UserNotificationRule("my_user_step_5",
            user_id=my_user.id,
            position=4,
            type="notify_by_slack")
        my_user_important_step1 = grafana.on_call.UserNotificationRule("my_user_important_step_1",
            user_id=my_user.id,
            important=True,
            position=0,
            type="notify_by_mobile_app_critical")
        my_user_important_step2 = grafana.on_call.UserNotificationRule("my_user_important_step_2",
            user_id=my_user.id,
            important=True,
            position=1,
            duration=300,
            type="wait")
        my_user_important_step3 = grafana.on_call.UserNotificationRule("my_user_important_step_3",
            user_id=my_user.id,
            important=True,
            position=2,
            type="notify_by_mobile_app_critical")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:onCall/userNotificationRule:UserNotificationRule name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param UserNotificationRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserNotificationRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 important: Optional[pulumi.Input[bool]] = None,
                 position: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserNotificationRuleArgs.__new__(UserNotificationRuleArgs)

            __props__.__dict__["duration"] = duration
            __props__.__dict__["important"] = important
            __props__.__dict__["position"] = position
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/oncallUserNotificationRule:OncallUserNotificationRule")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(UserNotificationRule, __self__).__init__(
            'grafana:onCall/userNotificationRule:UserNotificationRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            duration: Optional[pulumi.Input[int]] = None,
            important: Optional[pulumi.Input[bool]] = None,
            position: Optional[pulumi.Input[int]] = None,
            type: Optional[pulumi.Input[str]] = None,
            user_id: Optional[pulumi.Input[str]] = None) -> 'UserNotificationRule':
        """
        Get an existing UserNotificationRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] duration: A time in seconds to wait (when `type=wait`). Can be 60, 300, 900, 1800, 3600
        :param pulumi.Input[bool] important: Boolean value which indicates if a rule is “important”
        :param pulumi.Input[int] position: Personal notification rules execute one after another starting from position=0. A new escalation policy created with a position of an existing escalation policy will move the old one (and all following) down on the list.
        :param pulumi.Input[str] type: The type of notification rule. Can be wait, notify*by*slack, notify*by*msteams, notify*by*sms, notify*by*phone*call, notify*by*telegram, notify*by*email, notify*by*mobile*app, notify*by*mobile*app*critical. NOTE: `notify_by_msteams` is only available for Grafana Cloud customers.
        :param pulumi.Input[str] user_id: User ID
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserNotificationRuleState.__new__(_UserNotificationRuleState)

        __props__.__dict__["duration"] = duration
        __props__.__dict__["important"] = important
        __props__.__dict__["position"] = position
        __props__.__dict__["type"] = type
        __props__.__dict__["user_id"] = user_id
        return UserNotificationRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Output[Optional[int]]:
        """
        A time in seconds to wait (when `type=wait`). Can be 60, 300, 900, 1800, 3600
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter
    def important(self) -> pulumi.Output[bool]:
        """
        Boolean value which indicates if a rule is “important”
        """
        return pulumi.get(self, "important")

    @property
    @pulumi.getter
    def position(self) -> pulumi.Output[Optional[int]]:
        """
        Personal notification rules execute one after another starting from position=0. A new escalation policy created with a position of an existing escalation policy will move the old one (and all following) down on the list.
        """
        return pulumi.get(self, "position")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The type of notification rule. Can be wait, notify*by*slack, notify*by*msteams, notify*by*sms, notify*by*phone*call, notify*by*telegram, notify*by*email, notify*by*mobile*app, notify*by*mobile*app*critical. NOTE: `notify_by_msteams` is only available for Grafana Cloud customers.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[str]:
        """
        User ID
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetOncallUserResult',
    'AwaitableGetOncallUserResult',
    'get_oncall_user',
    'get_oncall_user_output',
]

warnings.warn("""grafana.index/getoncalluser.getOncallUser has been deprecated in favor of grafana.oncall/getuser.getUser""", DeprecationWarning)

@pulumi.output_type
class GetOncallUserResult:
    """
    A collection of values returned by getOncallUser.
    """
    def __init__(__self__, email=None, id=None, role=None, username=None):
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if role and not isinstance(role, str):
            raise TypeError("Expected argument 'role' to be a str")
        pulumi.set(__self__, "role", role)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def email(self) -> str:
        """
        The email of the user.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the user.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def role(self) -> str:
        """
        The role of the user.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter
    def username(self) -> str:
        """
        The username of the user.
        """
        return pulumi.get(self, "username")


class AwaitableGetOncallUserResult(GetOncallUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOncallUserResult(
            email=self.email,
            id=self.id,
            role=self.role,
            username=self.username)


def get_oncall_user(username: Optional[str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOncallUserResult:
    """
    * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/users/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    alex = grafana.onCall.get_user(username="alex")
    ```


    :param str username: The username of the user.
    """
    pulumi.log.warn("""get_oncall_user is deprecated: grafana.index/getoncalluser.getOncallUser has been deprecated in favor of grafana.oncall/getuser.getUser""")
    __args__ = dict()
    __args__['username'] = username
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:index/getOncallUser:getOncallUser', __args__, opts=opts, typ=GetOncallUserResult).value

    return AwaitableGetOncallUserResult(
        email=pulumi.get(__ret__, 'email'),
        id=pulumi.get(__ret__, 'id'),
        role=pulumi.get(__ret__, 'role'),
        username=pulumi.get(__ret__, 'username'))
def get_oncall_user_output(username: Optional[pulumi.Input[str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOncallUserResult]:
    """
    * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/users/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    alex = grafana.onCall.get_user(username="alex")
    ```


    :param str username: The username of the user.
    """
    pulumi.log.warn("""get_oncall_user is deprecated: grafana.index/getoncalluser.getOncallUser has been deprecated in favor of grafana.oncall/getuser.getUser""")
    __args__ = dict()
    __args__['username'] = username
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:index/getOncallUser:getOncallUser', __args__, opts=opts, typ=GetOncallUserResult)
    return __ret__.apply(lambda __response__: GetOncallUserResult(
        email=pulumi.get(__response__, 'email'),
        id=pulumi.get(__response__, 'id'),
        role=pulumi.get(__response__, 'role'),
        username=pulumi.get(__response__, 'username')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetLibraryPanelResult',
    'AwaitableGetLibraryPanelResult',
    'get_library_panel',
    'get_library_panel_output',
]

warnings.warn("""grafana.index/getlibrarypanel.getLibraryPanel has been deprecated in favor of grafana.oss/getlibrarypanel.getLibraryPanel""", DeprecationWarning)

@pulumi.output_type
class GetLibraryPanelResult:
    """
    A collection of values returned by getLibraryPanel.
    """
    def __init__(__self__, created=None, dashboard_ids=None, description=None, folder_name=None, folder_uid=None, id=None, model_json=None, name=None, org_id=None, panel_id=None, type=None, uid=None, updated=None, version=None):
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if dashboard_ids and not isinstance(dashboard_ids, list):
            raise TypeError("Expected argument 'dashboard_ids' to be a list")
        pulumi.set(__self__, "dashboard_ids", dashboard_ids)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if folder_name and not isinstance(folder_name, str):
            raise TypeError("Expected argument 'folder_name' to be a str")
        pulumi.set(__self__, "folder_name", folder_name)
        if folder_uid and not isinstance(folder_uid, str):
            raise TypeError("Expected argument 'folder_uid' to be a str")
        pulumi.set(__self__, "folder_uid", folder_uid)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if model_json and not isinstance(model_json, str):
            raise TypeError("Expected argument 'model_json' to be a str")
        pulumi.set(__self__, "model_json", model_json)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if panel_id and not isinstance(panel_id, int):
            raise TypeError("Expected argument 'panel_id' to be a int")
        pulumi.set(__self__, "panel_id", panel_id)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if uid and not isinstance(uid, str):
            raise TypeError("Expected argument 'uid' to be a str")
        pulumi.set(__self__, "uid", uid)
        if updated and not isinstance(updated, str):
            raise TypeError("Expected argument 'updated' to be a str")
        pulumi.set(__self__, "updated", updated)
        if version and not isinstance(version, int):
            raise TypeError("Expected argument 'version' to be a int")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def created(self) -> str:
        """
        Timestamp when the library panel was created.
        """
        return pulumi.get(self, "created")

    @property
    @pulumi.getter(name="dashboardIds")
    def dashboard_ids(self) -> Sequence[int]:
        """
        Numerical IDs of Grafana dashboards containing the library panel.
        """
        return pulumi.get(self, "dashboard_ids")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description of the library panel.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="folderName")
    def folder_name(self) -> str:
        """
        Name of the folder containing the library panel.
        """
        return pulumi.get(self, "folder_name")

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> str:
        """
        Unique ID (UID) of the folder containing the library panel.
        """
        return pulumi.get(self, "folder_uid")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="modelJson")
    def model_json(self) -> str:
        """
        The JSON model for the library panel.
        """
        return pulumi.get(self, "model_json")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Name of the library panel.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[str]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="panelId")
    def panel_id(self) -> int:
        """
        The numeric ID of the library panel computed by Grafana.
        """
        return pulumi.get(self, "panel_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Type of the library panel (eg. text).
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def uid(self) -> Optional[str]:
        """
        The unique identifier (UID) of the library panel.
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter
    def updated(self) -> str:
        """
        Timestamp when the library panel was last modified.
        """
        return pulumi.get(self, "updated")

    @property
    @pulumi.getter
    def version(self) -> int:
        """
        Version of the library panel.
        """
        return pulumi.get(self, "version")


class AwaitableGetLibraryPanelResult(GetLibraryPanelResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLibraryPanelResult(
            created=self.created,
            dashboard_ids=self.dashboard_ids,
            description=self.description,
            folder_name=self.folder_name,
            folder_uid=self.folder_uid,
            id=self.id,
            model_json=self.model_json,
            name=self.name,
            org_id=self.org_id,
            panel_id=self.panel_id,
            type=self.type,
            uid=self.uid,
            updated=self.updated,
            version=self.version)


def get_library_panel(name: Optional[str] = None,
                      org_id: Optional[str] = None,
                      uid: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLibraryPanelResult:
    """
    Data source for retrieving a single library panel by name or uid.


    :param str name: Name of the library panel.
    :param str org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
    :param str uid: The unique identifier (UID) of the library panel.
    """
    pulumi.log.warn("""get_library_panel is deprecated: grafana.index/getlibrarypanel.getLibraryPanel has been deprecated in favor of grafana.oss/getlibrarypanel.getLibraryPanel""")
    __args__ = dict()
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['uid'] = uid
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:index/getLibraryPanel:getLibraryPanel', __args__, opts=opts, typ=GetLibraryPanelResult).value

    return AwaitableGetLibraryPanelResult(
        created=pulumi.get(__ret__, 'created'),
        dashboard_ids=pulumi.get(__ret__, 'dashboard_ids'),
        description=pulumi.get(__ret__, 'description'),
        folder_name=pulumi.get(__ret__, 'folder_name'),
        folder_uid=pulumi.get(__ret__, 'folder_uid'),
        id=pulumi.get(__ret__, 'id'),
        model_json=pulumi.get(__ret__, 'model_json'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        panel_id=pulumi.get(__ret__, 'panel_id'),
        type=pulumi.get(__ret__, 'type'),
        uid=pulumi.get(__ret__, 'uid'),
        updated=pulumi.get(__ret__, 'updated'),
        version=pulumi.get(__ret__, 'version'))
def get_library_panel_output(name: Optional[pulumi.Input[Optional[str]]] = None,
                             org_id: Optional[pulumi.Input[Optional[str]]] = None,
                             uid: Optional[pulumi.Input[Optional[str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLibraryPanelResult]:
    """
    Data source for retrieving a single library panel by name or uid.


    :param str name: Name of the library panel.
    :param str org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
    :param str uid: The unique identifier (UID) of the library panel.
    """
    pulumi.log.warn("""get_library_panel is deprecated: grafana.index/getlibrarypanel.getLibraryPanel has been deprecated in favor of grafana.oss/getlibrarypanel.getLibraryPanel""")
    __args__ = dict()
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['uid'] = uid
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:index/getLibraryPanel:getLibraryPanel', __args__, opts=opts, typ=GetLibraryPanelResult)
    return __ret__.apply(lambda __response__: GetLibraryPanelResult(
        created=pulumi.get(__response__, 'created'),
        dashboard_ids=pulumi.get(__response__, 'dashboard_ids'),
        description=pulumi.get(__response__, 'description'),
        folder_name=pulumi.get(__response__, 'folder_name'),
        folder_uid=pulumi.get(__response__, 'folder_uid'),
        id=pulumi.get(__response__, 'id'),
        model_json=pulumi.get(__response__, 'model_json'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        panel_id=pulumi.get(__response__, 'panel_id'),
        type=pulumi.get(__response__, 'type'),
        uid=pulumi.get(__response__, 'uid'),
        updated=pulumi.get(__response__, 'updated'),
        version=pulumi.get(__response__, 'version')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SLOArgs', 'SLO']

@pulumi.input_type
class SLOArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[str],
                 destination_datasource: pulumi.Input['SLODestinationDatasourceArgs'],
                 objectives: pulumi.Input[Sequence[pulumi.Input['SLOObjectiveArgs']]],
                 queries: pulumi.Input[Sequence[pulumi.Input['SLOQueryArgs']]],
                 alertings: Optional[pulumi.Input[Sequence[pulumi.Input['SLOAlertingArgs']]]] = None,
                 folder_uid: Optional[pulumi.Input[str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input['SLOLabelArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 search_expression: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SLO resource.
        :param pulumi.Input[str] description: Description is a free-text field that can provide more context to an SLO.
        :param pulumi.Input['SLODestinationDatasourceArgs'] destination_datasource: Destination Datasource sets the datasource defined for an SLO
        :param pulumi.Input[Sequence[pulumi.Input['SLOObjectiveArgs']]] objectives: Over each rolling time window, the remaining error budget will be calculated, and separate alerts can be generated for each time window based on the SLO burn rate or remaining error budget.
        :param pulumi.Input[Sequence[pulumi.Input['SLOQueryArgs']]] queries: Query describes the indicator that will be measured against the objective. Freeform Query types are currently supported.
        :param pulumi.Input[Sequence[pulumi.Input['SLOAlertingArgs']]] alertings: Configures the alerting rules that will be generated for each
               			time window associated with the SLO. Grafana SLOs can generate
               			alerts when the short-term error budget burn is very high, the
               			long-term error budget burn rate is high, or when the remaining
               			error budget is below a certain threshold. Annotations and Labels support templating.
        :param pulumi.Input[str] folder_uid: UID for the SLO folder
        :param pulumi.Input[Sequence[pulumi.Input['SLOLabelArgs']]] labels: Additional labels that will be attached to all metrics generated from the query. These labels are useful for grouping SLOs in dashboard views that you create by hand. Labels must adhere to Prometheus label name schema - "^[a-zA-Z*][a-zA-Z0-9*]*$"
        :param pulumi.Input[str] name: Name should be a short description of your indicator. Consider names like "API Availability"
        :param pulumi.Input[str] search_expression: The name of a search expression in Grafana Asserts. This is used in the SLO UI to open the Asserts RCA workbench and in alerts to link to the RCA workbench.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "destination_datasource", destination_datasource)
        pulumi.set(__self__, "objectives", objectives)
        pulumi.set(__self__, "queries", queries)
        if alertings is not None:
            pulumi.set(__self__, "alertings", alertings)
        if folder_uid is not None:
            pulumi.set(__self__, "folder_uid", folder_uid)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if search_expression is not None:
            pulumi.set(__self__, "search_expression", search_expression)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[str]:
        """
        Description is a free-text field that can provide more context to an SLO.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationDatasource")
    def destination_datasource(self) -> pulumi.Input['SLODestinationDatasourceArgs']:
        """
        Destination Datasource sets the datasource defined for an SLO
        """
        return pulumi.get(self, "destination_datasource")

    @destination_datasource.setter
    def destination_datasource(self, value: pulumi.Input['SLODestinationDatasourceArgs']):
        pulumi.set(self, "destination_datasource", value)

    @property
    @pulumi.getter
    def objectives(self) -> pulumi.Input[Sequence[pulumi.Input['SLOObjectiveArgs']]]:
        """
        Over each rolling time window, the remaining error budget will be calculated, and separate alerts can be generated for each time window based on the SLO burn rate or remaining error budget.
        """
        return pulumi.get(self, "objectives")

    @objectives.setter
    def objectives(self, value: pulumi.Input[Sequence[pulumi.Input['SLOObjectiveArgs']]]):
        pulumi.set(self, "objectives", value)

    @property
    @pulumi.getter
    def queries(self) -> pulumi.Input[Sequence[pulumi.Input['SLOQueryArgs']]]:
        """
        Query describes the indicator that will be measured against the objective. Freeform Query types are currently supported.
        """
        return pulumi.get(self, "queries")

    @queries.setter
    def queries(self, value: pulumi.Input[Sequence[pulumi.Input['SLOQueryArgs']]]):
        pulumi.set(self, "queries", value)

    @property
    @pulumi.getter
    def alertings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SLOAlertingArgs']]]]:
        """
        Configures the alerting rules that will be generated for each
        			time window associated with the SLO. Grafana SLOs can generate
        			alerts when the short-term error budget burn is very high, the
        			long-term error budget burn rate is high, or when the remaining
        			error budget is below a certain threshold. Annotations and Labels support templating.
        """
        return pulumi.get(self, "alertings")

    @alertings.setter
    def alertings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SLOAlertingArgs']]]]):
        pulumi.set(self, "alertings", value)

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> Optional[pulumi.Input[str]]:
        """
        UID for the SLO folder
        """
        return pulumi.get(self, "folder_uid")

    @folder_uid.setter
    def folder_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder_uid", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SLOLabelArgs']]]]:
        """
        Additional labels that will be attached to all metrics generated from the query. These labels are useful for grouping SLOs in dashboard views that you create by hand. Labels must adhere to Prometheus label name schema - "^[a-zA-Z*][a-zA-Z0-9*]*$"
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SLOLabelArgs']]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name should be a short description of your indicator. Consider names like "API Availability"
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="searchExpression")
    def search_expression(self) -> Optional[pulumi.Input[str]]:
        """
        The name of a search expression in Grafana Asserts. This is used in the SLO UI to open the Asserts RCA workbench and in alerts to link to the RCA workbench.
        """
        return pulumi.get(self, "search_expression")

    @search_expression.setter
    def search_expression(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "search_expression", value)


@pulumi.input_type
class _SLOState:
    def __init__(__self__, *,
                 alertings: Optional[pulumi.Input[Sequence[pulumi.Input['SLOAlertingArgs']]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 destination_datasource: Optional[pulumi.Input['SLODestinationDatasourceArgs']] = None,
                 folder_uid: Optional[pulumi.Input[str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input['SLOLabelArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 objectives: Optional[pulumi.Input[Sequence[pulumi.Input['SLOObjectiveArgs']]]] = None,
                 queries: Optional[pulumi.Input[Sequence[pulumi.Input['SLOQueryArgs']]]] = None,
                 search_expression: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SLO resources.
        :param pulumi.Input[Sequence[pulumi.Input['SLOAlertingArgs']]] alertings: Configures the alerting rules that will be generated for each
               			time window associated with the SLO. Grafana SLOs can generate
               			alerts when the short-term error budget burn is very high, the
               			long-term error budget burn rate is high, or when the remaining
               			error budget is below a certain threshold. Annotations and Labels support templating.
        :param pulumi.Input[str] description: Description is a free-text field that can provide more context to an SLO.
        :param pulumi.Input['SLODestinationDatasourceArgs'] destination_datasource: Destination Datasource sets the datasource defined for an SLO
        :param pulumi.Input[str] folder_uid: UID for the SLO folder
        :param pulumi.Input[Sequence[pulumi.Input['SLOLabelArgs']]] labels: Additional labels that will be attached to all metrics generated from the query. These labels are useful for grouping SLOs in dashboard views that you create by hand. Labels must adhere to Prometheus label name schema - "^[a-zA-Z*][a-zA-Z0-9*]*$"
        :param pulumi.Input[str] name: Name should be a short description of your indicator. Consider names like "API Availability"
        :param pulumi.Input[Sequence[pulumi.Input['SLOObjectiveArgs']]] objectives: Over each rolling time window, the remaining error budget will be calculated, and separate alerts can be generated for each time window based on the SLO burn rate or remaining error budget.
        :param pulumi.Input[Sequence[pulumi.Input['SLOQueryArgs']]] queries: Query describes the indicator that will be measured against the objective. Freeform Query types are currently supported.
        :param pulumi.Input[str] search_expression: The name of a search expression in Grafana Asserts. This is used in the SLO UI to open the Asserts RCA workbench and in alerts to link to the RCA workbench.
        """
        if alertings is not None:
            pulumi.set(__self__, "alertings", alertings)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_datasource is not None:
            pulumi.set(__self__, "destination_datasource", destination_datasource)
        if folder_uid is not None:
            pulumi.set(__self__, "folder_uid", folder_uid)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if objectives is not None:
            pulumi.set(__self__, "objectives", objectives)
        if queries is not None:
            pulumi.set(__self__, "queries", queries)
        if search_expression is not None:
            pulumi.set(__self__, "search_expression", search_expression)

    @property
    @pulumi.getter
    def alertings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SLOAlertingArgs']]]]:
        """
        Configures the alerting rules that will be generated for each
        			time window associated with the SLO. Grafana SLOs can generate
        			alerts when the short-term error budget burn is very high, the
        			long-term error budget burn rate is high, or when the remaining
        			error budget is below a certain threshold. Annotations and Labels support templating.
        """
        return pulumi.get(self, "alertings")

    @alertings.setter
    def alertings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SLOAlertingArgs']]]]):
        pulumi.set(self, "alertings", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description is a free-text field that can provide more context to an SLO.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationDatasource")
    def destination_datasource(self) -> Optional[pulumi.Input['SLODestinationDatasourceArgs']]:
        """
        Destination Datasource sets the datasource defined for an SLO
        """
        return pulumi.get(self, "destination_datasource")

    @destination_datasource.setter
    def destination_datasource(self, value: Optional[pulumi.Input['SLODestinationDatasourceArgs']]):
        pulumi.set(self, "destination_datasource", value)

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> Optional[pulumi.Input[str]]:
        """
        UID for the SLO folder
        """
        return pulumi.get(self, "folder_uid")

    @folder_uid.setter
    def folder_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "folder_uid", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SLOLabelArgs']]]]:
        """
        Additional labels that will be attached to all metrics generated from the query. These labels are useful for grouping SLOs in dashboard views that you create by hand. Labels must adhere to Prometheus label name schema - "^[a-zA-Z*][a-zA-Z0-9*]*$"
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SLOLabelArgs']]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name should be a short description of your indicator. Consider names like "API Availability"
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def objectives(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SLOObjectiveArgs']]]]:
        """
        Over each rolling time window, the remaining error budget will be calculated, and separate alerts can be generated for each time window based on the SLO burn rate or remaining error budget.
        """
        return pulumi.get(self, "objectives")

    @objectives.setter
    def objectives(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SLOObjectiveArgs']]]]):
        pulumi.set(self, "objectives", value)

    @property
    @pulumi.getter
    def queries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SLOQueryArgs']]]]:
        """
        Query describes the indicator that will be measured against the objective. Freeform Query types are currently supported.
        """
        return pulumi.get(self, "queries")

    @queries.setter
    def queries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SLOQueryArgs']]]]):
        pulumi.set(self, "queries", value)

    @property
    @pulumi.getter(name="searchExpression")
    def search_expression(self) -> Optional[pulumi.Input[str]]:
        """
        The name of a search expression in Grafana Asserts. This is used in the SLO UI to open the Asserts RCA workbench and in alerts to link to the RCA workbench.
        """
        return pulumi.get(self, "search_expression")

    @search_expression.setter
    def search_expression(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "search_expression", value)


class SLO(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alertings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SLOAlertingArgs', 'SLOAlertingArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 destination_datasource: Optional[pulumi.Input[Union['SLODestinationDatasourceArgs', 'SLODestinationDatasourceArgsDict']]] = None,
                 folder_uid: Optional[pulumi.Input[str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SLOLabelArgs', 'SLOLabelArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 objectives: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SLOObjectiveArgs', 'SLOObjectiveArgsDict']]]]] = None,
                 queries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SLOQueryArgs', 'SLOQueryArgsDict']]]]] = None,
                 search_expression: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Resource manages Grafana SLOs.

        * [Official documentation](https://grafana.com/docs/grafana-cloud/alerting-and-irm/slo/)
        * [API documentation](https://grafana.com/docs/grafana-cloud/alerting-and-irm/slo/api/)
        * [Additional Information On Alerting Rule Annotations and Labels](https://prometheus.io/docs/prometheus/latest/configuration/alerting_rules/#templating/)

        ## Example Usage

        ### Ratio

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        ratio = grafana.slo.SLO("ratio",
            name="Terraform Testing - Ratio Query",
            description="Terraform Description - Ratio Query",
            queries=[{
                "ratio": {
                    "success_metric": "kubelet_http_requests_total{status!~\\"5..\\"}",
                    "total_metric": "kubelet_http_requests_total",
                    "group_by_labels": [
                        "job",
                        "instance",
                    ],
                },
                "type": "ratio",
            }],
            objectives=[{
                "value": 0.995,
                "window": "30d",
            }],
            destination_datasource={
                "uid": "grafanacloud-prom",
            },
            labels=[{
                "key": "slo",
                "value": "terraform",
            }],
            alertings=[{
                "fastburns": [{
                    "annotations": [
                        {
                            "key": "name",
                            "value": "SLO Burn Rate Very High",
                        },
                        {
                            "key": "description",
                            "value": "Error budget is burning too fast",
                        },
                    ],
                }],
                "slowburns": [{
                    "annotations": [
                        {
                            "key": "name",
                            "value": "SLO Burn Rate High",
                        },
                        {
                            "key": "description",
                            "value": "Error budget is burning too fast",
                        },
                    ],
                }],
            }])
        ```

        ### Advanced

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test = grafana.slo.SLO("test",
            name="Terraform Testing",
            description="Terraform Description",
            queries=[{
                "freeform": {
                    "query": "sum(rate(apiserver_request_total{code!=\\"500\\"}[$__rate_interval])) / sum(rate(apiserver_request_total[$__rate_interval]))",
                },
                "type": "freeform",
            }],
            objectives=[{
                "value": 0.995,
                "window": "30d",
            }],
            destination_datasource={
                "uid": "grafanacloud-prom",
            },
            labels=[{
                "key": "slo",
                "value": "terraform",
            }],
            alertings=[{
                "fastburns": [{
                    "annotations": [
                        {
                            "key": "name",
                            "value": "SLO Burn Rate Very High",
                        },
                        {
                            "key": "description",
                            "value": "Error budget is burning too fast",
                        },
                    ],
                }],
                "slowburns": [{
                    "annotations": [
                        {
                            "key": "name",
                            "value": "SLO Burn Rate High",
                        },
                        {
                            "key": "description",
                            "value": "Error budget is burning too fast",
                        },
                    ],
                }],
            }])
        ```

        ### Grafana Queries - Any supported datasource

        Grafana Queries use the grafana_queries field. It expects a JSON string list of valid grafana query JSON objects, the same as you'll find assigned to a Grafana Dashboard panel `targets` field.

        ```python
        import pulumi
        import json
        import pulumiverse_grafana as grafana

        test = grafana.slo.SLO("test",
            name="Terraform Testing",
            description="Terraform Description",
            queries=[{
                "grafana_queries": {
                    "grafana_queries": json.dumps([
                        {
                            "datasource": {
                                "type": "graphite",
                                "uid": "datasource-uid",
                            },
                            "refId": "Success",
                            "target": "groupByNode(perSecond(web.*.http.2xx_success.*.*), 3, 'avg')",
                        },
                        {
                            "datasource": {
                                "type": "graphite",
                                "uid": "datasource-uid",
                            },
                            "refId": "Total",
                            "target": "groupByNode(perSecond(web.*.http.5xx_errors.*.*), 3, 'avg')",
                        },
                        {
                            "datasource": {
                                "type": "__expr__",
                                "uid": "__expr__",
                            },
                            "expression": "$Success / $Total",
                            "refId": "Expression",
                            "type": "math",
                        },
                    ]),
                },
                "type": "grafana_queries",
            }],
            destination_datasource={
                "uid": "grafanacloud-prom",
            },
            objectives=[{
                "value": 0.995,
                "window": "30d",
            }],
            labels=[{
                "key": "slo",
                "value": "terraform",
            }],
            alertings=[{
                "fastburns": [{
                    "annotations": [
                        {
                            "key": "name",
                            "value": "SLO Burn Rate Very High",
                        },
                        {
                            "key": "description",
                            "value": "Error budget is burning too fast",
                        },
                    ],
                }],
                "slowburns": [{
                    "annotations": [
                        {
                            "key": "name",
                            "value": "SLO Burn Rate High",
                        },
                        {
                            "key": "description",
                            "value": "Error budget is burning too fast",
                        },
                    ],
                }],
            }])
        ```

        For a complete list, see [supported data sources](https://grafana.com/docs/grafana-cloud/alerting-and-irm/slo/set-up/additionaldatasources/#supported-data-sources).

        For additional help with SLOs, view our [documentation](https://grafana.com/docs/grafana-cloud/alerting-and-irm/slo/).

        ## Import

        ```sh
        $ pulumi import grafana:slo/sLO:SLO name "{{ uuid }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SLOAlertingArgs', 'SLOAlertingArgsDict']]]] alertings: Configures the alerting rules that will be generated for each
               			time window associated with the SLO. Grafana SLOs can generate
               			alerts when the short-term error budget burn is very high, the
               			long-term error budget burn rate is high, or when the remaining
               			error budget is below a certain threshold. Annotations and Labels support templating.
        :param pulumi.Input[str] description: Description is a free-text field that can provide more context to an SLO.
        :param pulumi.Input[Union['SLODestinationDatasourceArgs', 'SLODestinationDatasourceArgsDict']] destination_datasource: Destination Datasource sets the datasource defined for an SLO
        :param pulumi.Input[str] folder_uid: UID for the SLO folder
        :param pulumi.Input[Sequence[pulumi.Input[Union['SLOLabelArgs', 'SLOLabelArgsDict']]]] labels: Additional labels that will be attached to all metrics generated from the query. These labels are useful for grouping SLOs in dashboard views that you create by hand. Labels must adhere to Prometheus label name schema - "^[a-zA-Z*][a-zA-Z0-9*]*$"
        :param pulumi.Input[str] name: Name should be a short description of your indicator. Consider names like "API Availability"
        :param pulumi.Input[Sequence[pulumi.Input[Union['SLOObjectiveArgs', 'SLOObjectiveArgsDict']]]] objectives: Over each rolling time window, the remaining error budget will be calculated, and separate alerts can be generated for each time window based on the SLO burn rate or remaining error budget.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SLOQueryArgs', 'SLOQueryArgsDict']]]] queries: Query describes the indicator that will be measured against the objective. Freeform Query types are currently supported.
        :param pulumi.Input[str] search_expression: The name of a search expression in Grafana Asserts. This is used in the SLO UI to open the Asserts RCA workbench and in alerts to link to the RCA workbench.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SLOArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource manages Grafana SLOs.

        * [Official documentation](https://grafana.com/docs/grafana-cloud/alerting-and-irm/slo/)
        * [API documentation](https://grafana.com/docs/grafana-cloud/alerting-and-irm/slo/api/)
        * [Additional Information On Alerting Rule Annotations and Labels](https://prometheus.io/docs/prometheus/latest/configuration/alerting_rules/#templating/)

        ## Example Usage

        ### Ratio

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        ratio = grafana.slo.SLO("ratio",
            name="Terraform Testing - Ratio Query",
            description="Terraform Description - Ratio Query",
            queries=[{
                "ratio": {
                    "success_metric": "kubelet_http_requests_total{status!~\\"5..\\"}",
                    "total_metric": "kubelet_http_requests_total",
                    "group_by_labels": [
                        "job",
                        "instance",
                    ],
                },
                "type": "ratio",
            }],
            objectives=[{
                "value": 0.995,
                "window": "30d",
            }],
            destination_datasource={
                "uid": "grafanacloud-prom",
            },
            labels=[{
                "key": "slo",
                "value": "terraform",
            }],
            alertings=[{
                "fastburns": [{
                    "annotations": [
                        {
                            "key": "name",
                            "value": "SLO Burn Rate Very High",
                        },
                        {
                            "key": "description",
                            "value": "Error budget is burning too fast",
                        },
                    ],
                }],
                "slowburns": [{
                    "annotations": [
                        {
                            "key": "name",
                            "value": "SLO Burn Rate High",
                        },
                        {
                            "key": "description",
                            "value": "Error budget is burning too fast",
                        },
                    ],
                }],
            }])
        ```

        ### Advanced

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test = grafana.slo.SLO("test",
            name="Terraform Testing",
            description="Terraform Description",
            queries=[{
                "freeform": {
                    "query": "sum(rate(apiserver_request_total{code!=\\"500\\"}[$__rate_interval])) / sum(rate(apiserver_request_total[$__rate_interval]))",
                },
                "type": "freeform",
            }],
            objectives=[{
                "value": 0.995,
                "window": "30d",
            }],
            destination_datasource={
                "uid": "grafanacloud-prom",
            },
            labels=[{
                "key": "slo",
                "value": "terraform",
            }],
            alertings=[{
                "fastburns": [{
                    "annotations": [
                        {
                            "key": "name",
                            "value": "SLO Burn Rate Very High",
                        },
                        {
                            "key": "description",
                            "value": "Error budget is burning too fast",
                        },
                    ],
                }],
                "slowburns": [{
                    "annotations": [
                        {
                            "key": "name",
                            "value": "SLO Burn Rate High",
                        },
                        {
                            "key": "description",
                            "value": "Error budget is burning too fast",
                        },
                    ],
                }],
            }])
        ```

        ### Grafana Queries - Any supported datasource

        Grafana Queries use the grafana_queries field. It expects a JSON string list of valid grafana query JSON objects, the same as you'll find assigned to a Grafana Dashboard panel `targets` field.

        ```python
        import pulumi
        import json
        import pulumiverse_grafana as grafana

        test = grafana.slo.SLO("test",
            name="Terraform Testing",
            description="Terraform Description",
            queries=[{
                "grafana_queries": {
                    "grafana_queries": json.dumps([
                        {
                            "datasource": {
                                "type": "graphite",
                                "uid": "datasource-uid",
                            },
                            "refId": "Success",
                            "target": "groupByNode(perSecond(web.*.http.2xx_success.*.*), 3, 'avg')",
                        },
                        {
                            "datasource": {
                                "type": "graphite",
                                "uid": "datasource-uid",
                            },
                            "refId": "Total",
                            "target": "groupByNode(perSecond(web.*.http.5xx_errors.*.*), 3, 'avg')",
                        },
                        {
                            "datasource": {
                                "type": "__expr__",
                                "uid": "__expr__",
                            },
                            "expression": "$Success / $Total",
                            "refId": "Expression",
                            "type": "math",
                        },
                    ]),
                },
                "type": "grafana_queries",
            }],
            destination_datasource={
                "uid": "grafanacloud-prom",
            },
            objectives=[{
                "value": 0.995,
                "window": "30d",
            }],
            labels=[{
                "key": "slo",
                "value": "terraform",
            }],
            alertings=[{
                "fastburns": [{
                    "annotations": [
                        {
                            "key": "name",
                            "value": "SLO Burn Rate Very High",
                        },
                        {
                            "key": "description",
                            "value": "Error budget is burning too fast",
                        },
                    ],
                }],
                "slowburns": [{
                    "annotations": [
                        {
                            "key": "name",
                            "value": "SLO Burn Rate High",
                        },
                        {
                            "key": "description",
                            "value": "Error budget is burning too fast",
                        },
                    ],
                }],
            }])
        ```

        For a complete list, see [supported data sources](https://grafana.com/docs/grafana-cloud/alerting-and-irm/slo/set-up/additionaldatasources/#supported-data-sources).

        For additional help with SLOs, view our [documentation](https://grafana.com/docs/grafana-cloud/alerting-and-irm/slo/).

        ## Import

        ```sh
        $ pulumi import grafana:slo/sLO:SLO name "{{ uuid }}"
        ```

        :param str resource_name: The name of the resource.
        :param SLOArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SLOArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alertings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SLOAlertingArgs', 'SLOAlertingArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 destination_datasource: Optional[pulumi.Input[Union['SLODestinationDatasourceArgs', 'SLODestinationDatasourceArgsDict']]] = None,
                 folder_uid: Optional[pulumi.Input[str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SLOLabelArgs', 'SLOLabelArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 objectives: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SLOObjectiveArgs', 'SLOObjectiveArgsDict']]]]] = None,
                 queries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SLOQueryArgs', 'SLOQueryArgsDict']]]]] = None,
                 search_expression: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SLOArgs.__new__(SLOArgs)

            __props__.__dict__["alertings"] = alertings
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if destination_datasource is None and not opts.urn:
                raise TypeError("Missing required property 'destination_datasource'")
            __props__.__dict__["destination_datasource"] = destination_datasource
            __props__.__dict__["folder_uid"] = folder_uid
            __props__.__dict__["labels"] = labels
            __props__.__dict__["name"] = name
            if objectives is None and not opts.urn:
                raise TypeError("Missing required property 'objectives'")
            __props__.__dict__["objectives"] = objectives
            if queries is None and not opts.urn:
                raise TypeError("Missing required property 'queries'")
            __props__.__dict__["queries"] = queries
            __props__.__dict__["search_expression"] = search_expression
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/sLO:SLO")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(SLO, __self__).__init__(
            'grafana:slo/sLO:SLO',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alertings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SLOAlertingArgs', 'SLOAlertingArgsDict']]]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            destination_datasource: Optional[pulumi.Input[Union['SLODestinationDatasourceArgs', 'SLODestinationDatasourceArgsDict']]] = None,
            folder_uid: Optional[pulumi.Input[str]] = None,
            labels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SLOLabelArgs', 'SLOLabelArgsDict']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            objectives: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SLOObjectiveArgs', 'SLOObjectiveArgsDict']]]]] = None,
            queries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SLOQueryArgs', 'SLOQueryArgsDict']]]]] = None,
            search_expression: Optional[pulumi.Input[str]] = None) -> 'SLO':
        """
        Get an existing SLO resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SLOAlertingArgs', 'SLOAlertingArgsDict']]]] alertings: Configures the alerting rules that will be generated for each
               			time window associated with the SLO. Grafana SLOs can generate
               			alerts when the short-term error budget burn is very high, the
               			long-term error budget burn rate is high, or when the remaining
               			error budget is below a certain threshold. Annotations and Labels support templating.
        :param pulumi.Input[str] description: Description is a free-text field that can provide more context to an SLO.
        :param pulumi.Input[Union['SLODestinationDatasourceArgs', 'SLODestinationDatasourceArgsDict']] destination_datasource: Destination Datasource sets the datasource defined for an SLO
        :param pulumi.Input[str] folder_uid: UID for the SLO folder
        :param pulumi.Input[Sequence[pulumi.Input[Union['SLOLabelArgs', 'SLOLabelArgsDict']]]] labels: Additional labels that will be attached to all metrics generated from the query. These labels are useful for grouping SLOs in dashboard views that you create by hand. Labels must adhere to Prometheus label name schema - "^[a-zA-Z*][a-zA-Z0-9*]*$"
        :param pulumi.Input[str] name: Name should be a short description of your indicator. Consider names like "API Availability"
        :param pulumi.Input[Sequence[pulumi.Input[Union['SLOObjectiveArgs', 'SLOObjectiveArgsDict']]]] objectives: Over each rolling time window, the remaining error budget will be calculated, and separate alerts can be generated for each time window based on the SLO burn rate or remaining error budget.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SLOQueryArgs', 'SLOQueryArgsDict']]]] queries: Query describes the indicator that will be measured against the objective. Freeform Query types are currently supported.
        :param pulumi.Input[str] search_expression: The name of a search expression in Grafana Asserts. This is used in the SLO UI to open the Asserts RCA workbench and in alerts to link to the RCA workbench.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SLOState.__new__(_SLOState)

        __props__.__dict__["alertings"] = alertings
        __props__.__dict__["description"] = description
        __props__.__dict__["destination_datasource"] = destination_datasource
        __props__.__dict__["folder_uid"] = folder_uid
        __props__.__dict__["labels"] = labels
        __props__.__dict__["name"] = name
        __props__.__dict__["objectives"] = objectives
        __props__.__dict__["queries"] = queries
        __props__.__dict__["search_expression"] = search_expression
        return SLO(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def alertings(self) -> pulumi.Output[Optional[Sequence['outputs.SLOAlerting']]]:
        """
        Configures the alerting rules that will be generated for each
        			time window associated with the SLO. Grafana SLOs can generate
        			alerts when the short-term error budget burn is very high, the
        			long-term error budget burn rate is high, or when the remaining
        			error budget is below a certain threshold. Annotations and Labels support templating.
        """
        return pulumi.get(self, "alertings")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Description is a free-text field that can provide more context to an SLO.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="destinationDatasource")
    def destination_datasource(self) -> pulumi.Output['outputs.SLODestinationDatasource']:
        """
        Destination Datasource sets the datasource defined for an SLO
        """
        return pulumi.get(self, "destination_datasource")

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> pulumi.Output[Optional[str]]:
        """
        UID for the SLO folder
        """
        return pulumi.get(self, "folder_uid")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Optional[Sequence['outputs.SLOLabel']]]:
        """
        Additional labels that will be attached to all metrics generated from the query. These labels are useful for grouping SLOs in dashboard views that you create by hand. Labels must adhere to Prometheus label name schema - "^[a-zA-Z*][a-zA-Z0-9*]*$"
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name should be a short description of your indicator. Consider names like "API Availability"
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def objectives(self) -> pulumi.Output[Sequence['outputs.SLOObjective']]:
        """
        Over each rolling time window, the remaining error budget will be calculated, and separate alerts can be generated for each time window based on the SLO burn rate or remaining error budget.
        """
        return pulumi.get(self, "objectives")

    @property
    @pulumi.getter
    def queries(self) -> pulumi.Output[Sequence['outputs.SLOQuery']]:
        """
        Query describes the indicator that will be measured against the objective. Freeform Query types are currently supported.
        """
        return pulumi.get(self, "queries")

    @property
    @pulumi.getter(name="searchExpression")
    def search_expression(self) -> pulumi.Output[Optional[str]]:
        """
        The name of a search expression in Grafana Asserts. This is used in the SLO UI to open the Asserts RCA workbench and in alerts to link to the RCA workbench.
        """
        return pulumi.get(self, "search_expression")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetConnectionsMetricsEndpointScrapeJobResult',
    'AwaitableGetConnectionsMetricsEndpointScrapeJobResult',
    'get_connections_metrics_endpoint_scrape_job',
    'get_connections_metrics_endpoint_scrape_job_output',
]

warnings.warn("""grafana.index/getconnectionsmetricsendpointscrapejob.getConnectionsMetricsEndpointScrapeJob has been deprecated in favor of grafana.connections/getmetricsendpointscrapejob.getMetricsEndpointScrapeJob""", DeprecationWarning)

@pulumi.output_type
class GetConnectionsMetricsEndpointScrapeJobResult:
    """
    A collection of values returned by getConnectionsMetricsEndpointScrapeJob.
    """
    def __init__(__self__, authentication_basic_password=None, authentication_basic_username=None, authentication_bearer_token=None, authentication_method=None, enabled=None, id=None, name=None, scrape_interval_seconds=None, stack_id=None, url=None):
        if authentication_basic_password and not isinstance(authentication_basic_password, str):
            raise TypeError("Expected argument 'authentication_basic_password' to be a str")
        pulumi.set(__self__, "authentication_basic_password", authentication_basic_password)
        if authentication_basic_username and not isinstance(authentication_basic_username, str):
            raise TypeError("Expected argument 'authentication_basic_username' to be a str")
        pulumi.set(__self__, "authentication_basic_username", authentication_basic_username)
        if authentication_bearer_token and not isinstance(authentication_bearer_token, str):
            raise TypeError("Expected argument 'authentication_bearer_token' to be a str")
        pulumi.set(__self__, "authentication_bearer_token", authentication_bearer_token)
        if authentication_method and not isinstance(authentication_method, str):
            raise TypeError("Expected argument 'authentication_method' to be a str")
        pulumi.set(__self__, "authentication_method", authentication_method)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if scrape_interval_seconds and not isinstance(scrape_interval_seconds, int):
            raise TypeError("Expected argument 'scrape_interval_seconds' to be a int")
        pulumi.set(__self__, "scrape_interval_seconds", scrape_interval_seconds)
        if stack_id and not isinstance(stack_id, str):
            raise TypeError("Expected argument 'stack_id' to be a str")
        pulumi.set(__self__, "stack_id", stack_id)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="authenticationBasicPassword")
    def authentication_basic_password(self) -> str:
        """
        Password for basic authentication.
        """
        return pulumi.get(self, "authentication_basic_password")

    @property
    @pulumi.getter(name="authenticationBasicUsername")
    def authentication_basic_username(self) -> str:
        """
        Username for basic authentication.
        """
        return pulumi.get(self, "authentication_basic_username")

    @property
    @pulumi.getter(name="authenticationBearerToken")
    def authentication_bearer_token(self) -> str:
        """
        Token for authentication bearer.
        """
        return pulumi.get(self, "authentication_bearer_token")

    @property
    @pulumi.getter(name="authenticationMethod")
    def authentication_method(self) -> str:
        """
        Method to pass authentication credentials: basic or bearer.
        """
        return pulumi.get(self, "authentication_method")

    @property
    @pulumi.getter
    def enabled(self) -> bool:
        """
        Whether the metrics endpoint scrape job is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="scrapeIntervalSeconds")
    def scrape_interval_seconds(self) -> int:
        """
        Frequency for scraping the metrics endpoint: 30, 60, or 120 seconds.
        """
        return pulumi.get(self, "scrape_interval_seconds")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> str:
        return pulumi.get(self, "stack_id")

    @property
    @pulumi.getter
    def url(self) -> str:
        """
        The url to scrape metrics.
        """
        return pulumi.get(self, "url")


class AwaitableGetConnectionsMetricsEndpointScrapeJobResult(GetConnectionsMetricsEndpointScrapeJobResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConnectionsMetricsEndpointScrapeJobResult(
            authentication_basic_password=self.authentication_basic_password,
            authentication_basic_username=self.authentication_basic_username,
            authentication_bearer_token=self.authentication_bearer_token,
            authentication_method=self.authentication_method,
            enabled=self.enabled,
            id=self.id,
            name=self.name,
            scrape_interval_seconds=self.scrape_interval_seconds,
            stack_id=self.stack_id,
            url=self.url)


def get_connections_metrics_endpoint_scrape_job(name: Optional[str] = None,
                                                stack_id: Optional[str] = None,
                                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConnectionsMetricsEndpointScrapeJobResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    ds_test = grafana.connections.get_metrics_endpoint_scrape_job(stack_id="1",
        name="my-scrape-job")
    ```
    """
    pulumi.log.warn("""get_connections_metrics_endpoint_scrape_job is deprecated: grafana.index/getconnectionsmetricsendpointscrapejob.getConnectionsMetricsEndpointScrapeJob has been deprecated in favor of grafana.connections/getmetricsendpointscrapejob.getMetricsEndpointScrapeJob""")
    __args__ = dict()
    __args__['name'] = name
    __args__['stackId'] = stack_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:index/getConnectionsMetricsEndpointScrapeJob:getConnectionsMetricsEndpointScrapeJob', __args__, opts=opts, typ=GetConnectionsMetricsEndpointScrapeJobResult).value

    return AwaitableGetConnectionsMetricsEndpointScrapeJobResult(
        authentication_basic_password=pulumi.get(__ret__, 'authentication_basic_password'),
        authentication_basic_username=pulumi.get(__ret__, 'authentication_basic_username'),
        authentication_bearer_token=pulumi.get(__ret__, 'authentication_bearer_token'),
        authentication_method=pulumi.get(__ret__, 'authentication_method'),
        enabled=pulumi.get(__ret__, 'enabled'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        scrape_interval_seconds=pulumi.get(__ret__, 'scrape_interval_seconds'),
        stack_id=pulumi.get(__ret__, 'stack_id'),
        url=pulumi.get(__ret__, 'url'))
def get_connections_metrics_endpoint_scrape_job_output(name: Optional[pulumi.Input[str]] = None,
                                                       stack_id: Optional[pulumi.Input[str]] = None,
                                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetConnectionsMetricsEndpointScrapeJobResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    ds_test = grafana.connections.get_metrics_endpoint_scrape_job(stack_id="1",
        name="my-scrape-job")
    ```
    """
    pulumi.log.warn("""get_connections_metrics_endpoint_scrape_job is deprecated: grafana.index/getconnectionsmetricsendpointscrapejob.getConnectionsMetricsEndpointScrapeJob has been deprecated in favor of grafana.connections/getmetricsendpointscrapejob.getMetricsEndpointScrapeJob""")
    __args__ = dict()
    __args__['name'] = name
    __args__['stackId'] = stack_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:index/getConnectionsMetricsEndpointScrapeJob:getConnectionsMetricsEndpointScrapeJob', __args__, opts=opts, typ=GetConnectionsMetricsEndpointScrapeJobResult)
    return __ret__.apply(lambda __response__: GetConnectionsMetricsEndpointScrapeJobResult(
        authentication_basic_password=pulumi.get(__response__, 'authentication_basic_password'),
        authentication_basic_username=pulumi.get(__response__, 'authentication_basic_username'),
        authentication_bearer_token=pulumi.get(__response__, 'authentication_bearer_token'),
        authentication_method=pulumi.get(__response__, 'authentication_method'),
        enabled=pulumi.get(__response__, 'enabled'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        scrape_interval_seconds=pulumi.get(__response__, 'scrape_interval_seconds'),
        stack_id=pulumi.get(__response__, 'stack_id'),
        url=pulumi.get(__response__, 'url')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetDataSourceResult',
    'AwaitableGetDataSourceResult',
    'get_data_source',
    'get_data_source_output',
]

warnings.warn("""grafana.index/getdatasource.getDataSource has been deprecated in favor of grafana.oss/getdatasource.getDataSource""", DeprecationWarning)

@pulumi.output_type
class GetDataSourceResult:
    """
    A collection of values returned by getDataSource.
    """
    def __init__(__self__, access_mode=None, basic_auth_enabled=None, basic_auth_username=None, database_name=None, id=None, is_default=None, json_data_encoded=None, name=None, org_id=None, private_data_source_connect_network_id=None, type=None, uid=None, url=None, username=None):
        if access_mode and not isinstance(access_mode, str):
            raise TypeError("Expected argument 'access_mode' to be a str")
        pulumi.set(__self__, "access_mode", access_mode)
        if basic_auth_enabled and not isinstance(basic_auth_enabled, bool):
            raise TypeError("Expected argument 'basic_auth_enabled' to be a bool")
        pulumi.set(__self__, "basic_auth_enabled", basic_auth_enabled)
        if basic_auth_username and not isinstance(basic_auth_username, str):
            raise TypeError("Expected argument 'basic_auth_username' to be a str")
        pulumi.set(__self__, "basic_auth_username", basic_auth_username)
        if database_name and not isinstance(database_name, str):
            raise TypeError("Expected argument 'database_name' to be a str")
        pulumi.set(__self__, "database_name", database_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_default and not isinstance(is_default, bool):
            raise TypeError("Expected argument 'is_default' to be a bool")
        pulumi.set(__self__, "is_default", is_default)
        if json_data_encoded and not isinstance(json_data_encoded, str):
            raise TypeError("Expected argument 'json_data_encoded' to be a str")
        pulumi.set(__self__, "json_data_encoded", json_data_encoded)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if private_data_source_connect_network_id and not isinstance(private_data_source_connect_network_id, str):
            raise TypeError("Expected argument 'private_data_source_connect_network_id' to be a str")
        pulumi.set(__self__, "private_data_source_connect_network_id", private_data_source_connect_network_id)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if uid and not isinstance(uid, str):
            raise TypeError("Expected argument 'uid' to be a str")
        pulumi.set(__self__, "uid", uid)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="accessMode")
    def access_mode(self) -> str:
        """
        The method by which Grafana will access the data source: `proxy` or `direct`.
        """
        return pulumi.get(self, "access_mode")

    @property
    @pulumi.getter(name="basicAuthEnabled")
    def basic_auth_enabled(self) -> bool:
        """
        Whether to enable basic auth for the data source.
        """
        return pulumi.get(self, "basic_auth_enabled")

    @property
    @pulumi.getter(name="basicAuthUsername")
    def basic_auth_username(self) -> str:
        """
        Basic auth username.
        """
        return pulumi.get(self, "basic_auth_username")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> str:
        """
        (Required by some data source types) The name of the database to use on the selected data source server.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> bool:
        """
        Whether to set the data source as default. This should only be `true` to a single data source.
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="jsonDataEncoded")
    def json_data_encoded(self) -> str:
        """
        Serialized JSON string containing the json data. This attribute can be used to pass configuration options to the data source. To figure out what options a datasource has available, see its docs or inspect the network data when saving it from the Grafana UI. Note that keys in this map are usually camelCased.
        """
        return pulumi.get(self, "json_data_encoded")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[str]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="privateDataSourceConnectNetworkId")
    def private_data_source_connect_network_id(self) -> str:
        """
        (Can only be used with data sources in Grafana Cloud) The ID of the Private Data source Connect network to use with this data source.
        """
        return pulumi.get(self, "private_data_source_connect_network_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The data source type. Must be one of the supported data source keywords.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def uid(self) -> str:
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter
    def url(self) -> str:
        """
        The URL for the data source. The type of URL required varies depending on the chosen data source type.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def username(self) -> str:
        """
        (Required by some data source types) The username to use to authenticate to the data source.
        """
        return pulumi.get(self, "username")


class AwaitableGetDataSourceResult(GetDataSourceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDataSourceResult(
            access_mode=self.access_mode,
            basic_auth_enabled=self.basic_auth_enabled,
            basic_auth_username=self.basic_auth_username,
            database_name=self.database_name,
            id=self.id,
            is_default=self.is_default,
            json_data_encoded=self.json_data_encoded,
            name=self.name,
            org_id=self.org_id,
            private_data_source_connect_network_id=self.private_data_source_connect_network_id,
            type=self.type,
            uid=self.uid,
            url=self.url,
            username=self.username)


def get_data_source(name: Optional[str] = None,
                    org_id: Optional[str] = None,
                    uid: Optional[str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDataSourceResult:
    """
    Get details about a Grafana Datasource querying by either name, uid or ID

    ## Example Usage

    ```python
    import pulumi
    import json
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    prometheus = grafana.oss.DataSource("prometheus",
        type="prometheus",
        name="prometheus-ds-test",
        uid="prometheus-ds-test-uid",
        url="https://my-instance.com",
        basic_auth_enabled=True,
        basic_auth_username="username",
        json_data_encoded=json.dumps({
            "httpMethod": "POST",
            "prometheusType": "Mimir",
            "prometheusVersion": "2.4.0",
        }),
        secure_json_data_encoded=json.dumps({
            "basicAuthPassword": "password",
        }))
    from_name = grafana.oss.get_data_source_output(name=prometheus.name)
    from_uid = grafana.oss.get_data_source_output(uid=prometheus.uid)
    ```


    :param str org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
    """
    pulumi.log.warn("""get_data_source is deprecated: grafana.index/getdatasource.getDataSource has been deprecated in favor of grafana.oss/getdatasource.getDataSource""")
    __args__ = dict()
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['uid'] = uid
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:index/getDataSource:getDataSource', __args__, opts=opts, typ=GetDataSourceResult).value

    return AwaitableGetDataSourceResult(
        access_mode=pulumi.get(__ret__, 'access_mode'),
        basic_auth_enabled=pulumi.get(__ret__, 'basic_auth_enabled'),
        basic_auth_username=pulumi.get(__ret__, 'basic_auth_username'),
        database_name=pulumi.get(__ret__, 'database_name'),
        id=pulumi.get(__ret__, 'id'),
        is_default=pulumi.get(__ret__, 'is_default'),
        json_data_encoded=pulumi.get(__ret__, 'json_data_encoded'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        private_data_source_connect_network_id=pulumi.get(__ret__, 'private_data_source_connect_network_id'),
        type=pulumi.get(__ret__, 'type'),
        uid=pulumi.get(__ret__, 'uid'),
        url=pulumi.get(__ret__, 'url'),
        username=pulumi.get(__ret__, 'username'))
def get_data_source_output(name: Optional[pulumi.Input[Optional[str]]] = None,
                           org_id: Optional[pulumi.Input[Optional[str]]] = None,
                           uid: Optional[pulumi.Input[Optional[str]]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDataSourceResult]:
    """
    Get details about a Grafana Datasource querying by either name, uid or ID

    ## Example Usage

    ```python
    import pulumi
    import json
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    prometheus = grafana.oss.DataSource("prometheus",
        type="prometheus",
        name="prometheus-ds-test",
        uid="prometheus-ds-test-uid",
        url="https://my-instance.com",
        basic_auth_enabled=True,
        basic_auth_username="username",
        json_data_encoded=json.dumps({
            "httpMethod": "POST",
            "prometheusType": "Mimir",
            "prometheusVersion": "2.4.0",
        }),
        secure_json_data_encoded=json.dumps({
            "basicAuthPassword": "password",
        }))
    from_name = grafana.oss.get_data_source_output(name=prometheus.name)
    from_uid = grafana.oss.get_data_source_output(uid=prometheus.uid)
    ```


    :param str org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
    """
    pulumi.log.warn("""get_data_source is deprecated: grafana.index/getdatasource.getDataSource has been deprecated in favor of grafana.oss/getdatasource.getDataSource""")
    __args__ = dict()
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['uid'] = uid
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:index/getDataSource:getDataSource', __args__, opts=opts, typ=GetDataSourceResult)
    return __ret__.apply(lambda __response__: GetDataSourceResult(
        access_mode=pulumi.get(__response__, 'access_mode'),
        basic_auth_enabled=pulumi.get(__response__, 'basic_auth_enabled'),
        basic_auth_username=pulumi.get(__response__, 'basic_auth_username'),
        database_name=pulumi.get(__response__, 'database_name'),
        id=pulumi.get(__response__, 'id'),
        is_default=pulumi.get(__response__, 'is_default'),
        json_data_encoded=pulumi.get(__response__, 'json_data_encoded'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        private_data_source_connect_network_id=pulumi.get(__response__, 'private_data_source_connect_network_id'),
        type=pulumi.get(__response__, 'type'),
        uid=pulumi.get(__response__, 'uid'),
        url=pulumi.get(__response__, 'url'),
        username=pulumi.get(__response__, 'username')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RoleArgs', 'Role']

@pulumi.input_type
class RoleArgs:
    def __init__(__self__, *,
                 auto_increment_version: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 global_: Optional[pulumi.Input[bool]] = None,
                 group: Optional[pulumi.Input[str]] = None,
                 hidden: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input['RolePermissionArgs']]]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Role resource.
        :param pulumi.Input[bool] auto_increment_version: Whether the role version should be incremented automatically on updates (and set to 1 on creation). This field or `version` should be set.
        :param pulumi.Input[str] description: Description of the role.
        :param pulumi.Input[str] display_name: Display name of the role. Available with Grafana 8.5+.
        :param pulumi.Input[bool] global_: Boolean to state whether the role is available across all organizations or not. Defaults to `false`.
        :param pulumi.Input[str] group: Group of the role. Available with Grafana 8.5+.
        :param pulumi.Input[bool] hidden: Boolean to state whether the role should be visible in the Grafana UI or not. Available with Grafana 8.5+. Defaults to `false`.
        :param pulumi.Input[str] name: Name of the role
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input['RolePermissionArgs']]] permissions: Specific set of actions granted by the role.
        :param pulumi.Input[str] uid: Unique identifier of the role. Used for assignments.
        :param pulumi.Input[int] version: Version of the role. A role is updated only on version increase. This field or `auto_increment_version` should be set.
        """
        if auto_increment_version is not None:
            pulumi.set(__self__, "auto_increment_version", auto_increment_version)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if global_ is not None:
            pulumi.set(__self__, "global_", global_)
        if group is not None:
            pulumi.set(__self__, "group", group)
        if hidden is not None:
            pulumi.set(__self__, "hidden", hidden)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="autoIncrementVersion")
    def auto_increment_version(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the role version should be incremented automatically on updates (and set to 1 on creation). This field or `version` should be set.
        """
        return pulumi.get(self, "auto_increment_version")

    @auto_increment_version.setter
    def auto_increment_version(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_increment_version", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the role.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        Display name of the role. Available with Grafana 8.5+.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="global")
    def global_(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean to state whether the role is available across all organizations or not. Defaults to `false`.
        """
        return pulumi.get(self, "global_")

    @global_.setter
    def global_(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "global_", value)

    @property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[str]]:
        """
        Group of the role. Available with Grafana 8.5+.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group", value)

    @property
    @pulumi.getter
    def hidden(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean to state whether the role should be visible in the Grafana UI or not. Available with Grafana 8.5+. Defaults to `false`.
        """
        return pulumi.get(self, "hidden")

    @hidden.setter
    def hidden(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "hidden", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the role
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RolePermissionArgs']]]]:
        """
        Specific set of actions granted by the role.
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RolePermissionArgs']]]]):
        pulumi.set(self, "permissions", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier of the role. Used for assignments.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "uid", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[int]]:
        """
        Version of the role. A role is updated only on version increase. This field or `auto_increment_version` should be set.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "version", value)


@pulumi.input_type
class _RoleState:
    def __init__(__self__, *,
                 auto_increment_version: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 global_: Optional[pulumi.Input[bool]] = None,
                 group: Optional[pulumi.Input[str]] = None,
                 hidden: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input['RolePermissionArgs']]]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering Role resources.
        :param pulumi.Input[bool] auto_increment_version: Whether the role version should be incremented automatically on updates (and set to 1 on creation). This field or `version` should be set.
        :param pulumi.Input[str] description: Description of the role.
        :param pulumi.Input[str] display_name: Display name of the role. Available with Grafana 8.5+.
        :param pulumi.Input[bool] global_: Boolean to state whether the role is available across all organizations or not. Defaults to `false`.
        :param pulumi.Input[str] group: Group of the role. Available with Grafana 8.5+.
        :param pulumi.Input[bool] hidden: Boolean to state whether the role should be visible in the Grafana UI or not. Available with Grafana 8.5+. Defaults to `false`.
        :param pulumi.Input[str] name: Name of the role
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input['RolePermissionArgs']]] permissions: Specific set of actions granted by the role.
        :param pulumi.Input[str] uid: Unique identifier of the role. Used for assignments.
        :param pulumi.Input[int] version: Version of the role. A role is updated only on version increase. This field or `auto_increment_version` should be set.
        """
        if auto_increment_version is not None:
            pulumi.set(__self__, "auto_increment_version", auto_increment_version)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if global_ is not None:
            pulumi.set(__self__, "global_", global_)
        if group is not None:
            pulumi.set(__self__, "group", group)
        if hidden is not None:
            pulumi.set(__self__, "hidden", hidden)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="autoIncrementVersion")
    def auto_increment_version(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the role version should be incremented automatically on updates (and set to 1 on creation). This field or `version` should be set.
        """
        return pulumi.get(self, "auto_increment_version")

    @auto_increment_version.setter
    def auto_increment_version(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_increment_version", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the role.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        Display name of the role. Available with Grafana 8.5+.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="global")
    def global_(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean to state whether the role is available across all organizations or not. Defaults to `false`.
        """
        return pulumi.get(self, "global_")

    @global_.setter
    def global_(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "global_", value)

    @property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[str]]:
        """
        Group of the role. Available with Grafana 8.5+.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group", value)

    @property
    @pulumi.getter
    def hidden(self) -> Optional[pulumi.Input[bool]]:
        """
        Boolean to state whether the role should be visible in the Grafana UI or not. Available with Grafana 8.5+. Defaults to `false`.
        """
        return pulumi.get(self, "hidden")

    @hidden.setter
    def hidden(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "hidden", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the role
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RolePermissionArgs']]]]:
        """
        Specific set of actions granted by the role.
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RolePermissionArgs']]]]):
        pulumi.set(self, "permissions", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier of the role. Used for assignments.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "uid", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[int]]:
        """
        Version of the role. A role is updated only on version increase. This field or `auto_increment_version` should be set.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "version", value)


class Role(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_increment_version: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 global_: Optional[pulumi.Input[bool]] = None,
                 group: Optional[pulumi.Input[str]] = None,
                 hidden: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RolePermissionArgs', 'RolePermissionArgsDict']]]]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        **Note:** This resource is available only with Grafana Enterprise 8.+.

        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/roles-and-permissions/access-control/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/access_control/)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        super_user = grafana.enterprise.Role("super_user",
            name="Super User",
            description="My Super User description",
            uid="superuseruid",
            version=1,
            global_=True,
            permissions=[
                {
                    "action": "org.users:add",
                    "scope": "users:*",
                },
                {
                    "action": "org.users:write",
                    "scope": "users:*",
                },
                {
                    "action": "org.users:read",
                    "scope": "users:*",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import grafana:enterprise/role:Role name "{{ uid }}"
        ```

        ```sh
        $ pulumi import grafana:enterprise/role:Role name "{{ orgID }}:{{ uid }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_increment_version: Whether the role version should be incremented automatically on updates (and set to 1 on creation). This field or `version` should be set.
        :param pulumi.Input[str] description: Description of the role.
        :param pulumi.Input[str] display_name: Display name of the role. Available with Grafana 8.5+.
        :param pulumi.Input[bool] global_: Boolean to state whether the role is available across all organizations or not. Defaults to `false`.
        :param pulumi.Input[str] group: Group of the role. Available with Grafana 8.5+.
        :param pulumi.Input[bool] hidden: Boolean to state whether the role should be visible in the Grafana UI or not. Available with Grafana 8.5+. Defaults to `false`.
        :param pulumi.Input[str] name: Name of the role
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RolePermissionArgs', 'RolePermissionArgsDict']]]] permissions: Specific set of actions granted by the role.
        :param pulumi.Input[str] uid: Unique identifier of the role. Used for assignments.
        :param pulumi.Input[int] version: Version of the role. A role is updated only on version increase. This field or `auto_increment_version` should be set.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[RoleArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        **Note:** This resource is available only with Grafana Enterprise 8.+.

        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/roles-and-permissions/access-control/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/access_control/)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        super_user = grafana.enterprise.Role("super_user",
            name="Super User",
            description="My Super User description",
            uid="superuseruid",
            version=1,
            global_=True,
            permissions=[
                {
                    "action": "org.users:add",
                    "scope": "users:*",
                },
                {
                    "action": "org.users:write",
                    "scope": "users:*",
                },
                {
                    "action": "org.users:read",
                    "scope": "users:*",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import grafana:enterprise/role:Role name "{{ uid }}"
        ```

        ```sh
        $ pulumi import grafana:enterprise/role:Role name "{{ orgID }}:{{ uid }}"
        ```

        :param str resource_name: The name of the resource.
        :param RoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_increment_version: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 global_: Optional[pulumi.Input[bool]] = None,
                 group: Optional[pulumi.Input[str]] = None,
                 hidden: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RolePermissionArgs', 'RolePermissionArgsDict']]]]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RoleArgs.__new__(RoleArgs)

            __props__.__dict__["auto_increment_version"] = auto_increment_version
            __props__.__dict__["description"] = description
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["global_"] = global_
            __props__.__dict__["group"] = group
            __props__.__dict__["hidden"] = hidden
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["permissions"] = permissions
            __props__.__dict__["uid"] = uid
            __props__.__dict__["version"] = version
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/role:Role")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(Role, __self__).__init__(
            'grafana:enterprise/role:Role',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_increment_version: Optional[pulumi.Input[bool]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            global_: Optional[pulumi.Input[bool]] = None,
            group: Optional[pulumi.Input[str]] = None,
            hidden: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            permissions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RolePermissionArgs', 'RolePermissionArgsDict']]]]] = None,
            uid: Optional[pulumi.Input[str]] = None,
            version: Optional[pulumi.Input[int]] = None) -> 'Role':
        """
        Get an existing Role resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_increment_version: Whether the role version should be incremented automatically on updates (and set to 1 on creation). This field or `version` should be set.
        :param pulumi.Input[str] description: Description of the role.
        :param pulumi.Input[str] display_name: Display name of the role. Available with Grafana 8.5+.
        :param pulumi.Input[bool] global_: Boolean to state whether the role is available across all organizations or not. Defaults to `false`.
        :param pulumi.Input[str] group: Group of the role. Available with Grafana 8.5+.
        :param pulumi.Input[bool] hidden: Boolean to state whether the role should be visible in the Grafana UI or not. Available with Grafana 8.5+. Defaults to `false`.
        :param pulumi.Input[str] name: Name of the role
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RolePermissionArgs', 'RolePermissionArgsDict']]]] permissions: Specific set of actions granted by the role.
        :param pulumi.Input[str] uid: Unique identifier of the role. Used for assignments.
        :param pulumi.Input[int] version: Version of the role. A role is updated only on version increase. This field or `auto_increment_version` should be set.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RoleState.__new__(_RoleState)

        __props__.__dict__["auto_increment_version"] = auto_increment_version
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["global_"] = global_
        __props__.__dict__["group"] = group
        __props__.__dict__["hidden"] = hidden
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["permissions"] = permissions
        __props__.__dict__["uid"] = uid
        __props__.__dict__["version"] = version
        return Role(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoIncrementVersion")
    def auto_increment_version(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the role version should be incremented automatically on updates (and set to 1 on creation). This field or `version` should be set.
        """
        return pulumi.get(self, "auto_increment_version")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description of the role.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[str]]:
        """
        Display name of the role. Available with Grafana 8.5+.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="global")
    def global_(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean to state whether the role is available across all organizations or not. Defaults to `false`.
        """
        return pulumi.get(self, "global_")

    @property
    @pulumi.getter
    def group(self) -> pulumi.Output[Optional[str]]:
        """
        Group of the role. Available with Grafana 8.5+.
        """
        return pulumi.get(self, "group")

    @property
    @pulumi.getter
    def hidden(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean to state whether the role should be visible in the Grafana UI or not. Available with Grafana 8.5+. Defaults to `false`.
        """
        return pulumi.get(self, "hidden")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the role
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def permissions(self) -> pulumi.Output[Optional[Sequence['outputs.RolePermission']]]:
        """
        Specific set of actions granted by the role.
        """
        return pulumi.get(self, "permissions")

    @property
    @pulumi.getter
    def uid(self) -> pulumi.Output[str]:
        """
        Unique identifier of the role. Used for assignments.
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[Optional[int]]:
        """
        Version of the role. A role is updated only on version increase. This field or `auto_increment_version` should be set.
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FolderArgs', 'Folder']

@pulumi.input_type
class FolderArgs:
    def __init__(__self__, *,
                 title: pulumi.Input[str],
                 org_id: Optional[pulumi.Input[str]] = None,
                 parent_folder_uid: Optional[pulumi.Input[str]] = None,
                 prevent_destroy_if_not_empty: Optional[pulumi.Input[bool]] = None,
                 uid: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Folder resource.
        :param pulumi.Input[str] title: The title of the folder.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] parent_folder_uid: The uid of the parent folder. If set, the folder will be nested. If not set, the folder will be created in the root folder. Note: This requires the nestedFolders feature flag to be enabled on your Grafana instance.
        :param pulumi.Input[bool] prevent_destroy_if_not_empty: Prevent deletion of the folder if it is not empty (contains dashboards or alert rules). This feature requires Grafana 10.2 or later. Defaults to `false`.
        :param pulumi.Input[str] uid: Unique identifier.
        """
        pulumi.set(__self__, "title", title)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if parent_folder_uid is not None:
            pulumi.set(__self__, "parent_folder_uid", parent_folder_uid)
        if prevent_destroy_if_not_empty is not None:
            pulumi.set(__self__, "prevent_destroy_if_not_empty", prevent_destroy_if_not_empty)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)

    @property
    @pulumi.getter
    def title(self) -> pulumi.Input[str]:
        """
        The title of the folder.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[str]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="parentFolderUid")
    def parent_folder_uid(self) -> Optional[pulumi.Input[str]]:
        """
        The uid of the parent folder. If set, the folder will be nested. If not set, the folder will be created in the root folder. Note: This requires the nestedFolders feature flag to be enabled on your Grafana instance.
        """
        return pulumi.get(self, "parent_folder_uid")

    @parent_folder_uid.setter
    def parent_folder_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "parent_folder_uid", value)

    @property
    @pulumi.getter(name="preventDestroyIfNotEmpty")
    def prevent_destroy_if_not_empty(self) -> Optional[pulumi.Input[bool]]:
        """
        Prevent deletion of the folder if it is not empty (contains dashboards or alert rules). This feature requires Grafana 10.2 or later. Defaults to `false`.
        """
        return pulumi.get(self, "prevent_destroy_if_not_empty")

    @prevent_destroy_if_not_empty.setter
    def prevent_destroy_if_not_empty(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "prevent_destroy_if_not_empty", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "uid", value)


@pulumi.input_type
class _FolderState:
    def __init__(__self__, *,
                 org_id: Optional[pulumi.Input[str]] = None,
                 parent_folder_uid: Optional[pulumi.Input[str]] = None,
                 prevent_destroy_if_not_empty: Optional[pulumi.Input[bool]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Folder resources.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] parent_folder_uid: The uid of the parent folder. If set, the folder will be nested. If not set, the folder will be created in the root folder. Note: This requires the nestedFolders feature flag to be enabled on your Grafana instance.
        :param pulumi.Input[bool] prevent_destroy_if_not_empty: Prevent deletion of the folder if it is not empty (contains dashboards or alert rules). This feature requires Grafana 10.2 or later. Defaults to `false`.
        :param pulumi.Input[str] title: The title of the folder.
        :param pulumi.Input[str] uid: Unique identifier.
        :param pulumi.Input[str] url: The full URL of the folder.
        """
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if parent_folder_uid is not None:
            pulumi.set(__self__, "parent_folder_uid", parent_folder_uid)
        if prevent_destroy_if_not_empty is not None:
            pulumi.set(__self__, "prevent_destroy_if_not_empty", prevent_destroy_if_not_empty)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="parentFolderUid")
    def parent_folder_uid(self) -> Optional[pulumi.Input[str]]:
        """
        The uid of the parent folder. If set, the folder will be nested. If not set, the folder will be created in the root folder. Note: This requires the nestedFolders feature flag to be enabled on your Grafana instance.
        """
        return pulumi.get(self, "parent_folder_uid")

    @parent_folder_uid.setter
    def parent_folder_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "parent_folder_uid", value)

    @property
    @pulumi.getter(name="preventDestroyIfNotEmpty")
    def prevent_destroy_if_not_empty(self) -> Optional[pulumi.Input[bool]]:
        """
        Prevent deletion of the folder if it is not empty (contains dashboards or alert rules). This feature requires Grafana 10.2 or later. Defaults to `false`.
        """
        return pulumi.get(self, "prevent_destroy_if_not_empty")

    @prevent_destroy_if_not_empty.setter
    def prevent_destroy_if_not_empty(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "prevent_destroy_if_not_empty", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        The title of the folder.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "uid", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[str]]:
        """
        The full URL of the folder.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "url", value)


class Folder(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 parent_folder_uid: Optional[pulumi.Input[str]] = None,
                 prevent_destroy_if_not_empty: Optional[pulumi.Input[bool]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/manage-dashboards/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/folder/)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test_folder = grafana.oss.Folder("test_folder", title="Terraform Test Folder")
        test_folder_dashboard = grafana.oss.Dashboard("test_folder",
            folder=test_folder.id,
            config_json=\"\"\"{
          "title": "Dashboard in folder",
          "uid": "dashboard-in-folder"
        }
        \"\"\")
        test_folder_with_uid = grafana.oss.Folder("test_folder_with_uid",
            uid="test-folder-uid",
            title="Terraform Test Folder With UID")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:oss/folder:Folder name "{{ uid }}"
        ```

        ```sh
        $ pulumi import grafana:oss/folder:Folder name "{{ orgID }}:{{ uid }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] parent_folder_uid: The uid of the parent folder. If set, the folder will be nested. If not set, the folder will be created in the root folder. Note: This requires the nestedFolders feature flag to be enabled on your Grafana instance.
        :param pulumi.Input[bool] prevent_destroy_if_not_empty: Prevent deletion of the folder if it is not empty (contains dashboards or alert rules). This feature requires Grafana 10.2 or later. Defaults to `false`.
        :param pulumi.Input[str] title: The title of the folder.
        :param pulumi.Input[str] uid: Unique identifier.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FolderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/manage-dashboards/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/folder/)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test_folder = grafana.oss.Folder("test_folder", title="Terraform Test Folder")
        test_folder_dashboard = grafana.oss.Dashboard("test_folder",
            folder=test_folder.id,
            config_json=\"\"\"{
          "title": "Dashboard in folder",
          "uid": "dashboard-in-folder"
        }
        \"\"\")
        test_folder_with_uid = grafana.oss.Folder("test_folder_with_uid",
            uid="test-folder-uid",
            title="Terraform Test Folder With UID")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:oss/folder:Folder name "{{ uid }}"
        ```

        ```sh
        $ pulumi import grafana:oss/folder:Folder name "{{ orgID }}:{{ uid }}"
        ```

        :param str resource_name: The name of the resource.
        :param FolderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FolderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 parent_folder_uid: Optional[pulumi.Input[str]] = None,
                 prevent_destroy_if_not_empty: Optional[pulumi.Input[bool]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FolderArgs.__new__(FolderArgs)

            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["parent_folder_uid"] = parent_folder_uid
            __props__.__dict__["prevent_destroy_if_not_empty"] = prevent_destroy_if_not_empty
            if title is None and not opts.urn:
                raise TypeError("Missing required property 'title'")
            __props__.__dict__["title"] = title
            __props__.__dict__["uid"] = uid
            __props__.__dict__["url"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/folder:Folder")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(Folder, __self__).__init__(
            'grafana:oss/folder:Folder',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            parent_folder_uid: Optional[pulumi.Input[str]] = None,
            prevent_destroy_if_not_empty: Optional[pulumi.Input[bool]] = None,
            title: Optional[pulumi.Input[str]] = None,
            uid: Optional[pulumi.Input[str]] = None,
            url: Optional[pulumi.Input[str]] = None) -> 'Folder':
        """
        Get an existing Folder resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[str] parent_folder_uid: The uid of the parent folder. If set, the folder will be nested. If not set, the folder will be created in the root folder. Note: This requires the nestedFolders feature flag to be enabled on your Grafana instance.
        :param pulumi.Input[bool] prevent_destroy_if_not_empty: Prevent deletion of the folder if it is not empty (contains dashboards or alert rules). This feature requires Grafana 10.2 or later. Defaults to `false`.
        :param pulumi.Input[str] title: The title of the folder.
        :param pulumi.Input[str] uid: Unique identifier.
        :param pulumi.Input[str] url: The full URL of the folder.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FolderState.__new__(_FolderState)

        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["parent_folder_uid"] = parent_folder_uid
        __props__.__dict__["prevent_destroy_if_not_empty"] = prevent_destroy_if_not_empty
        __props__.__dict__["title"] = title
        __props__.__dict__["uid"] = uid
        __props__.__dict__["url"] = url
        return Folder(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="parentFolderUid")
    def parent_folder_uid(self) -> pulumi.Output[Optional[str]]:
        """
        The uid of the parent folder. If set, the folder will be nested. If not set, the folder will be created in the root folder. Note: This requires the nestedFolders feature flag to be enabled on your Grafana instance.
        """
        return pulumi.get(self, "parent_folder_uid")

    @property
    @pulumi.getter(name="preventDestroyIfNotEmpty")
    def prevent_destroy_if_not_empty(self) -> pulumi.Output[Optional[bool]]:
        """
        Prevent deletion of the folder if it is not empty (contains dashboards or alert rules). This feature requires Grafana 10.2 or later. Defaults to `false`.
        """
        return pulumi.get(self, "prevent_destroy_if_not_empty")

    @property
    @pulumi.getter
    def title(self) -> pulumi.Output[str]:
        """
        The title of the folder.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter
    def uid(self) -> pulumi.Output[str]:
        """
        Unique identifier.
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[str]:
        """
        The full URL of the folder.
        """
        return pulumi.get(self, "url")

